@@ -21,6 +21,7 @@ Tests for `sphinx_feature_classification` module.
 import os
 
 import ddt
+import fixtures
 import six
 from six.moves import configparser
 
@@ -50,6 +51,8 @@ class MatrixTestCase(base.TestCase):
         fake_feature = self.matrix.features[0]
         self.assertEqual('Cool Feature', fake_feature.title)
         self.assertEqual('optional', fake_feature.status)
+        self.assertEqual('openstack get coolness *', fake_feature.cli)
+        self.assertEqual('get-coolness', fake_feature.api)
         self.assertEqual('A pretty darn cool feature.',
                          fake_feature.notes)
 
@@ -72,3 +75,15 @@ class MatrixTestCase(base.TestCase):
         fake_implementation = self.matrix.features[0].implementations[key]
         self.assertEqual(status, fake_implementation.status)
         self.assertEqual(notes, fake_implementation.notes)
+
+    def test_on_build_finished(self):
+
+        class FakeApp(object):
+            outdir = self.useFixture(fixtures.TempDir()).path
+
+        app = FakeApp()
+        exc = None
+        support_matrix.on_build_finished(app, exc)
+        expected_file = os.path.join(
+            app.outdir, '_static', 'support-matrix.css')
+        self.assertTrue(os.path.isfile(expected_file))
